#
# spec file for package libepoxy
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libepoxy
%define sonum	0
Version:        1.4.3
Release:        lp152.4.5
Summary:        OpenGL function pointer management library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://github.com/anholt/libepoxy
Source0:        https://github.com/anholt/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  meson >= 0.39.1
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv1_cm)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xorg-macros)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Epoxy is a library for handling OpenGL function pointer management for you.

It hides the complexity of dlopen(), dlsym(), glXGetProcAddress(),
eglGetProcAddress(), etc. from the app developer, with very little knowledge
needed on their part. They get to read GL specs and write code using undecorated
function names like glCompileShader().

%package -n %{name}%{sonum}
Summary:        OpenGL function pointer management library
Group:          Development/Libraries/C and C++

%description -n %{name}%{sonum}
Epoxy is a library for handling OpenGL function pointer management for you.

It hides the complexity of dlopen(), dlsym(), glXGetProcAddress(),
eglGetProcAddress(), etc. from the app developer, with very little knowledge
needed on their part. They get to read GL specs and write code using undecorated
function names like glCompileShader().

%package devel
Summary:        Development files for libepoxy
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sonum} = %{version}
Requires:       pkgconfig(x11)
Requires:       pkgconfig(egl)
Requires:       glibc-devel

%description devel
Epoxy is a library for handling OpenGL function pointer management for you.

It hides the complexity of dlopen(), dlsym(), glXGetProcAddress(),
eglGetProcAddress(), etc. from the app developer, with very little knowledge
needed on their part. They get to read GL specs and write code using undecorated
function names like glCompileShader().

Development files.

%prep
%setup -q

%build
%{meson}
%{meson_build}

%install
%{meson_install}
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{name}%{sonum} -p /sbin/ldconfig

%postun -n %{name}%{sonum} -p /sbin/ldconfig

%files -n %{name}%{sonum}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libepoxy.so.*

%files devel
%defattr(-,root,root)
%doc README.md
%{_libdir}/libepoxy.so
%{_libdir}/pkgconfig/epoxy.pc
%{_includedir}/epoxy/

%changelog
* Wed Jan 10 2018 crrodriguez@opensuse.org
- -devel package requires pkgconfig(x11), pkgconfig(egl)
  but those deps are not generated automatically.
* Tue Jun  6 2017 zaitor@opensuse.org
- Update to version 1.4.3:
  + Require Meson 0.39.1; the previous release already had an
    implicit requirement on this version.
  + Allow disabling EGL support when building Epoxy.
  + Add support for building on Haiku.
  + Update EGL registry from Khronos.
- Switch to meson build:
  + Drop autoconf, automake and libtool BuildRequires, and drop
    conditional autogen.sh call.
  + Add meson BuildRequires and add meson macros, drop autotools
    macros.
- Correct docs installed.
- Use "Full and pretty" source name.
- Run spec-cleaner.
- Add pkgconfig(glesv1_cm) and pkgconfig(glesv2) BuildRequires:
  Build the optional gles v1 and v2 support.
* Sun Jun  4 2017 zaitor@opensuse.org
- Update to version 1.4.2:
  * Add C++ guards around generated headers.
  * Add z,relro and z,now to the GCC linker flags.
  * Add explicit version flags for macOS builds.
  * Add missing visibility compiler flags.
  * Prefer using pkg-config files to find GLES.
  * Fix build on MSVC 2013 when using the inline keyword.
  * Fix dlwrap on aarch64.
  * Require Meson ≥ 0.38.1.
  * Allow building Epoxy as a Meson sub-project.
  * Avoid crashes when running Epoxy on X servers without GLX.
* Sat Mar  4 2017 zaitor@opensuse.org
- Update to version 1.4.1:
  * Find the appropriate version of the Python interpreter when
    building.
  * Ensure that the dispatch generation script works with Python
    2.x and 3.x.
  * Ensure that Epoxy builds correctly under Windows.
  * Fix location of the m4 macros in the autotools build.
- Changes from version 1.4.0:
  * Epoxy can now build with MSVC versions prior to 2013; we still
    recommend using a recent, C99-compatible compiler, like MSVC
    2015.
  * When used under X11, Epoxy now attempts to handle the cases
    where the GLX extension is not built or not available.
  * GLX can now be enabled and disabled at configuration time; this
    allows building Epoxy with GLX on macOS, and allows building
    Epoxy without GLX on embedded platforms.
  * Epoxy now exposes API that lets dependent projects safely check
    if platform API like GLX and EGL is available at run time.
  * EGL support has been improved on Windows, and made more
    resilient on other platforms.
  * Epoxy supports building with the Meson build system, which has
    Ninja, Visual Studio, and XCode backends.
  * Epoxy can generate its API reference using Doxygen (currently
    only available on Meson builds).
  * The GL registry has been updated with the latest version of the
    API references provided by Khronos; Epoxy now supports the API
    introduced by OpenGL 4.5.
* Mon Jul 20 2015 hrvoje.senjan@gmail.com
- Update to 1.3.1
  * brown-paper-bag fix to unexport another private symbol that we'd
    leaked, noticed when I went diffing the exported symbols between
    v1.2 and v1.3 for the debian build.
- Changes since 1.3.0:
  * MSVC 2013 support.
  * OSX drops GLX support.
  * Updates to the registry
  * Fixes for a nonconformant GL implementation
  * Library size reductions
  * Reproducible builds
- Drop u_sort-the-providers-by-their-enum-not-by-their-functi.patch,
  merged upstream
* Thu Mar 26 2015 zaitor@opensuse.org
- Add baselibs.conf in order to build 32bit packages.
* Thu Feb 12 2015 sndirsch@suse.com
- u_sort-the-providers-by-their-enum-not-by-their-functi.patch
  * sort the providers by their enum not by their function name;
    patch by coolo (bnc#917533)
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Update to 1.2
  * This is a bugfix and feature release. On the feature side of
  things, it brings in an updated registry with support for
  GLES 3.1 and EGL 1.5, along with miscellaneous other extensions,
  and many more aliases for GLES functions. On the bugfix side,
  it should be much more portable to non-Mesa drivers (nvidia binary
  in particular) and systems with mixed Mesa and non-Mesa drivers,
  and actually install the wgl headers in the windows build.
- Explicitly BuildRequire pkgconfig(x11), and don't count other
  packages drag it in
- Drop git_fixes.patch, merged upstream
* Wed Feb 26 2014 hrvoje.senjan@gmail.com
- Init libepoxy package
